.. shxarray documentation master file, created by
   sphinx-quickstart on Fri Dec  8 22:28:53 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Welcome to xinv's documentation!
====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   introduction.rst   
   installation.rst
   tutorial.rst
   api.rst
   dev.rst
   changelog.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
